---
title: '[2023년 10월] 개인정보처리방침 개정 변경 안내'
category: 공지사항
tags:
  - 공지사항
datetime: 2023-10-29T15:00:00.000Z
---

안녕하세요\~! 포트원 입니다.항상 포트원을 이용해주시는 고객 여러분께 진심으로 감사드립니다.

2023년 11월 30일 아래와 같이 개인정보처리방침이 변경됨을 사전 안내 드립니다.

- 공고일 : 2023.10.30(월)
- 시행일 : 2023.11.30(목)
